#!/usr/bin/env node
"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const crypto_1 = __importDefault(require("./crypto"));
const listr2_1 = require("listr2");
const tasks = __importStar(require("./tasks"));
const utils_1 = require("./utils");
const [filePath = '', password = '', op = ''] = process.argv.slice(2);
(async function main() {
    if (filePath && password && op === '-e') {
        return console.log(await crypto_1.default.encrypt(filePath, password));
    }
    else if (filePath && password && op === '-d') {
        return console.log(await crypto_1.default.decrypt(filePath, password));
    }
    const listr = new listr2_1.Listr([
        {
            title: 'Load Config File',
            task: (_, task) => {
                return task.newListr([
                    tasks.createFileFormatVerifyTask(filePath),
                    tasks.createLoadFileTask(filePath),
                    tasks.createDecryptFileTask(filePath, password),
                    tasks.createParseFileTask(filePath)
                ]);
            }
        },
        {
            title: 'Create Temporary Download Directory',
            task: tasks.createGenerateTmpDirectoryTask()
        },
        {
            title: 'Install Apps',
            skip: (ctx) => !ctx.tasks.some((task) => (0, utils_1.isAppType)(task)),
            task: (ctx, task) => task.newListr(tasks.createInstallAppTasks(ctx), {
                rendererOptions: { collapse: false }
            })
        },
        {
            title: 'Change Default Settings',
            skip: (ctx) => !ctx.tasks.some((task) => (0, utils_1.isCommandType)(task)),
            task: (ctx, task) => task.newListr(tasks.createExecCommandTasks(ctx), {
                exitOnError: false,
                rendererOptions: { collapse: false }
            })
        },
        {
            title: 'Remove Temporary Download Directory',
            task: tasks.createRemoveTmpDirectoryTask()
        }
    ], {
        concurrent: false,
        exitOnError: true,
        registerSignalListeners: false,
        rendererOptions: { collapse: true, collapseErrors: false }
    });
    try {
        const result = await listr.run({
            text: '',
            tasks: [],
            tmpdir: '',
            filePaths: new Map()
        });
        if (hasCommandTask(result)) {
            console.log('\n', chalk_1.default.bgGreen('Tips'), chalk_1.default.green("A change in the system default settings is detected, it's recommended to logout or restart system"), '\n');
        }
    }
    catch (error) {
        error;
    }
})();
function hasCommandTask(result) {
    return !!result.tasks.filter((task) => (0, utils_1.isCommandType)(task)).length;
}
