"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.decrypt = exports.encrypt = exports.resolveMasUrl = exports.loadFile = exports.isRemotelyFile = exports.isLocallyFile = exports.isGistFile = exports.isHashCode = exports.isMasUrl = exports.isCommandType = exports.isAppType = exports.isPackFile = exports.parse = void 0;
const axios_1 = __importDefault(require("axios"));
const js_yaml_1 = __importDefault(require("js-yaml"));
const crypto_1 = __importDefault(require("crypto"));
const path_1 = require("path");
const fs_1 = require("fs");
function parse(text) {
    try {
        return (text ? js_yaml_1.default.load(text) : {});
    }
    catch (error) {
        return {};
    }
}
exports.parse = parse;
function isPackFile(filePath) {
    return (0, path_1.extname)(filePath) === '.pack';
}
exports.isPackFile = isPackFile;
function isAppType(obj) {
    return obj.type === 'app';
}
exports.isAppType = isAppType;
function isCommandType(obj) {
    return obj.type === 'command';
}
exports.isCommandType = isCommandType;
function isMasUrl(url) {
    try {
        return new URL(url).hostname === 'apps.apple.com';
    }
    catch (error) {
        return false;
    }
}
exports.isMasUrl = isMasUrl;
function isHashCode(text) {
    return new RegExp(`^[a-f0-9]{${text.length}}$`, 'gi').test(text);
}
exports.isHashCode = isHashCode;
function isGistFile(filePath) {
    return /^[a-z0-9.]+\/[a-z0-9.]+$/gi.test(filePath);
}
exports.isGistFile = isGistFile;
function isLocallyFile(filePath) {
    try {
        return (0, fs_1.lstatSync)(filePath).isFile();
    }
    catch (error) {
        return false;
    }
}
exports.isLocallyFile = isLocallyFile;
function isRemotelyFile(filePath) {
    try {
        return ['http:', 'https:'].includes(new URL(filePath).protocol);
    }
    catch (error) {
        return false;
    }
}
exports.isRemotelyFile = isRemotelyFile;
function loadFile(filePath) {
    return new Promise((resolve, reject) => {
        if (isLocallyFile(filePath)) {
            (0, fs_1.readFile)(filePath, 'utf8', (err, data) => (err ? reject(err) : resolve(data.trim())));
        }
        else if (isRemotelyFile(filePath)) {
            axios_1.default
                .get(filePath)
                .then(({ data }) => resolve(data.trim()))
                .catch((error) => reject(error));
        }
        else if (isGistFile(filePath)) {
            const [userName, gistName] = filePath.split('/');
            const url = `https://api.github.com/users/${userName}/gists`;
            axios_1.default
                .get(url)
                .then(({ data }) => getGistRawUrl(data, gistName))
                .then(async (url) => resolve(await loadFile(url)))
                .catch((error) => reject(error));
        }
        else {
            reject(new Error('The file not found'));
        }
    });
}
exports.loadFile = loadFile;
function resolveMasUrl(url) {
    try {
        const str = (0, path_1.basename)(new URL(url).pathname);
        return str.indexOf('id') === 0 ? str.replace('id', '') : '';
    }
    catch (error) {
        return '';
    }
}
exports.resolveMasUrl = resolveMasUrl;
function encrypt(data, password) {
    const algorithm = 'aes-256-cbc';
    const iv = crypto_1.default.createHash('md5').update(password).digest();
    const key = crypto_1.default.createHash('sha256').update(password).digest();
    const cipher = crypto_1.default.createCipheriv(algorithm, key, iv);
    return `${cipher.update(data, 'utf8', 'hex')}${cipher.final('hex')}`;
}
exports.encrypt = encrypt;
function decrypt(data, password) {
    const algorithm = 'aes-256-cbc';
    const iv = crypto_1.default.createHash('md5').update(password).digest();
    const key = crypto_1.default.createHash('sha256').update(password).digest();
    const decipher = crypto_1.default.createDecipheriv(algorithm, key, iv);
    return `${decipher.update(data, 'hex', 'utf8')}${decipher.final('utf8')}`;
}
exports.decrypt = decrypt;
function getGistRawUrl(gists, name) {
    for (const gist of gists) {
        if (gist.files && gist.files[name]) {
            return gist.files[name].raw_url;
        }
    }
    return '';
}
