"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const axios_1 = __importDefault(require("axios"));
const utils_1 = require("./utils");
const fs_1 = require("fs");
const path_1 = require("path");
function download(options) {
    return new Promise((resolve, reject) => {
        const fileName = (0, path_1.basename)(options.url);
        if (!(0, path_1.extname)(fileName)) {
            return reject(new Error('The download url format is invalid, must contain the ext name'));
        }
        axios_1.default
            .get(options.url, { responseType: 'stream' })
            .then((res, loaded = 0) => {
            const destPath = (0, path_1.join)(options.dir, fileName);
            const total = (0, utils_1.toInt)(res.headers['content-length']);
            if (options.onProgress) {
                res.data.on('data', (chunk) => {
                    loaded = loaded + chunk.length;
                    // @ts-ignore
                    options.onProgress({
                        total,
                        loaded,
                        percent: Math.floor(Math.min(Math.max(loaded / total, 0), 1) * 100).toFixed(0)
                    });
                });
            }
            res.data
                .pipe((0, fs_1.createWriteStream)(destPath))
                .on('close', () => resolve(destPath))
                .on('error', (error) => reject(error));
        })
            .catch((error) => reject(error));
    });
}
exports.default = download;
