"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const decompress_1 = __importDefault(require("decompress"));
const utils_1 = require("../utils");
exports.default = {
    installer: async function (filePath, dest) {
        try {
            const whoami = (0, utils_1.exec)('whoami').trim();
            if (utils_1.isAppleCPU) {
                await (0, utils_1.execute)(`
          mkdir -p ${dest}/etc ${dest}/include ${dest}/lib ${dest}/sbin ${dest}/share ${dest}/var ${dest}/opt ${dest}/share/zsh ${dest}/share/zsh/site-functions ${dest}/var/homebrew ${dest}/var/homebrew/linked ${dest}/Cellar ${dest}/Caskroom ${dest}/Frameworks &&
          chmod ug=rwx ${dest}/etc ${dest}/include ${dest}/lib ${dest}/sbin ${dest}/share ${dest}/var ${dest}/opt ${dest}/share/zsh ${dest}/share/zsh/site-functions ${dest}/var/homebrew ${dest}/var/homebrew/linked ${dest}/Cellar ${dest}/Caskroom ${dest}/Frameworks &&
          chmod go-w ${dest}/share/zsh ${dest}/share/zsh/site-functions &&
          chown ${whoami} ${dest}/etc ${dest}/include ${dest}/lib ${dest}/sbin ${dest}/share ${dest}/var ${dest}/opt ${dest}/share/zsh ${dest}/share/zsh/site-functions ${dest}/var/homebrew ${dest}/var/homebrew/linked ${dest}/Cellar ${dest}/Caskroom ${dest}/Frameworks &&
          chgrp admin ${dest}/etc ${dest}/include ${dest}/lib ${dest}/sbin ${dest}/share ${dest}/var ${dest}/opt ${dest}/share/zsh ${dest}/share/zsh/site-functions ${dest}/var/homebrew ${dest}/var/homebrew/linked ${dest}/Cellar ${dest}/Caskroom ${dest}/Frameworks &&
          chown -R ${whoami}:admin ${dest}
      `);
                await (0, decompress_1.default)(filePath, dest, { strip: 1 });
                await (0, utils_1.execute)(`
          echo '# Set PATH, MANPATH, etc., for Homebrew.' >> /Users/${whoami}/.zprofile &&
          echo 'eval "$(${dest}/bin/brew shellenv)"' >> /Users/${whoami}/.zprofile &&
          eval "$(${dest}/bin/brew shellenv)"
        `);
                return `${dest}/bin/brew`;
            }
            else {
                await (0, utils_1.execute)(`
          chmod u+rwx /usr/local/bin /usr/local/include /usr/local/lib /usr/local/share /usr/local/share/doc /usr/local/share/man /usr/local/share/man/man1 &&
          chmod g+rwx /usr/local/bin /usr/local/include /usr/local/lib /usr/local/share /usr/local/share/doc /usr/local/share/man /usr/local/share/man/man1 &&
          chown ${whoami} /usr/local/bin /usr/local/include /usr/local/lib /usr/local/share /usr/local/share/doc /usr/local/share/man /usr/local/share/man/man1 &&
          chgrp admin /usr/local/bin /usr/local/include /usr/local/lib /usr/local/share /usr/local/share/doc /usr/local/share/man /usr/local/share/man/man1 &&
          mkdir -p /usr/local/etc /usr/local/sbin /usr/local/var /usr/local/opt /usr/local/share/zsh /usr/local/share/zsh/site-functions /usr/local/var/homebrew /usr/local/var/homebrew/linked /usr/local/Cellar /usr/local/Caskroom /usr/local/Frameworks &&
          chmod ug=rwx /usr/local/etc /usr/local/sbin /usr/local/var /usr/local/opt /usr/local/share/zsh /usr/local/share/zsh/site-functions /usr/local/var/homebrew /usr/local/var/homebrew/linked /usr/local/Cellar /usr/local/Caskroom /usr/local/Frameworks &&
          chmod go-w /usr/local/share/zsh /usr/local/share/zsh/site-functions &&
          chown ${whoami} /usr/local/etc /usr/local/sbin /usr/local/var /usr/local/opt /usr/local/share/zsh /usr/local/share/zsh/site-functions /usr/local/var/homebrew /usr/local/var/homebrew/linked /usr/local/Cellar /usr/local/Caskroom /usr/local/Frameworks &&
          chgrp admin /usr/local/etc /usr/local/sbin /usr/local/var /usr/local/opt /usr/local/share/zsh /usr/local/share/zsh/site-functions /usr/local/var/homebrew /usr/local/var/homebrew/linked /usr/local/Cellar /usr/local/Caskroom /usr/local/Frameworks &&
          mkdir -p ${dest} &&
          chown -R ${whoami}:admin ${dest} &&
          mkdir -p /Users/${whoami}/Library/Caches/Homebrew &&
          chmod g+rwx /Users/${whoami}/Library/Caches/Homebrew &&
          chown -R ${whoami} /Users/${whoami}/Library/Caches/Homebrew
      `);
                await (0, decompress_1.default)(filePath, dest, { strip: 1 });
                await (0, utils_1.execute)(`ln -sf ${dest}/bin/brew /usr/local/bin/brew`);
                return '/usr/local/bin/brew';
            }
        }
        catch (error) {
            throw error.code === 'EEXIST' ? new Error('file already exists') : error;
        }
    },
    install: function (filePath) {
        const name = getAppName(filePath);
        const brewCommand = getBrewCommand();
        if (!brewCommand) {
            throw new Error('To download the application from Homebrew, you need to install brew first.');
        }
        if (isAlready(name)) {
            return (0, utils_1.which)(name);
        }
        const { stdout = '', stderr, code } = (0, utils_1.exec)(filePath.replace('brew', brewCommand));
        if (code === 0 && stdout !== '') {
            return (0, utils_1.which)(name);
        }
        else {
            throw new Error(stderr);
        }
    }
};
function getAppName(filePath) {
    return filePath.replace('brew install', '').trim();
}
function isAlready(name) {
    const { code } = (0, utils_1.exec)(`${getBrewCommand()} list ${name}`);
    return code === 0;
}
function getBrewCommand() {
    if ((0, utils_1.which)('brew')) {
        return (0, utils_1.which)('brew');
    }
    else if ((0, utils_1.which)(`${utils_1.Homebrew_DIR}/bin/brew`)) {
        return (0, utils_1.which)(`${utils_1.Homebrew_DIR}/bin/brew`);
    }
    else {
        return '';
    }
}
