"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const pkg_1 = __importDefault(require("./pkg"));
const utils_1 = require("../utils");
const path_1 = require("path");
const promises_1 = require("fs/promises");
const hdi_mac_1 = require("@shockpkg/hdi-mac");
async function undmg(filePath, dest) {
    let destPath = '';
    if (isAgreement(filePath)) {
        filePath = extract(filePath);
    }
    const mounter = new hdi_mac_1.Mounter();
    const diskImage = await mounter.attach(filePath, { nobrowse: true });
    const { mountPoint } = diskImage.devices.find((device) => device.mountPoint) || {};
    if (!mountPoint) {
        throw new Error('The mountPoint not found');
    }
    for (const file of await getMatchFiles(mountPoint)) {
        const extName = (0, path_1.extname)(file);
        const sourcePath = (0, path_1.join)(mountPoint, file);
        if (extName === '.app') {
            destPath = (0, utils_1.cp)(sourcePath, (0, path_1.join)(dest, file));
        }
        else if (extName === '.pkg') {
            destPath = await (0, pkg_1.default)(sourcePath, dest);
        }
    }
    await diskImage.eject();
    return destPath;
}
exports.default = undmg;
async function getMatchFiles(mountPoint) {
    const files = await (0, promises_1.readdir)(mountPoint);
    return files.filter((file) => /\.app?$/.test(file) || /\.pkg?$/.test(file));
}
function isAgreement(filePath) {
    const { code } = (0, utils_1.exec)(`hdiutil imageinfo ${filePath} | grep "Software License Agreement: true"`);
    return code === 0;
}
function extract(filePath) {
    const destPath = filePath.replace((0, path_1.extname)(filePath), '.cdr');
    const { code } = (0, utils_1.exec)(`hdiutil convert -quiet ${filePath} -format UDTO -o ${destPath}`);
    return code ? '' : destPath;
}
