"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const pkg_1 = __importDefault(require("./pkg"));
const path_1 = require("path");
const donwload_1 = __importDefault(require("../donwload"));
const utils_1 = require("../utils");
async function unmas(appid, dest) {
    if (!isLogined()) {
        throw new Error('To download apps from the Mac App Store, you need to login to your Apple ID manually.');
    }
    if (!(0, utils_1.which)('mas')) {
        await installMas();
    }
    let appName = '';
    const { stdout, stderr } = (0, utils_1.exec)(`mas install ${appid}`);
    if (stderr) {
        appName = stderr.replace('Warning: ', '').replace(' is already installed', '').trim();
    }
    else if (stdout) {
        appName = stdout.replace('==> Installed', '').trim();
    }
    return appName ? (0, path_1.join)(dest, `${appName}.app`) : '';
}
exports.default = unmas;
function isLogined() {
    const { stdout } = (0, utils_1.exec)('defaults read MobileMeAccounts | grep AccountID | cut -d \\" -f2');
    return !!stdout;
}
async function installMas() {
    const filePath = await (0, donwload_1.default)({
        url: utils_1.MAS_PKG_URL,
        dir: await (0, utils_1.tmpdir)()
    });
    if (utils_1.isAppleCPU && !isInstallRosetta()) {
        installRosetta2();
    }
    await (0, pkg_1.default)(filePath, utils_1.APP_DIR);
}
function isInstallRosetta() {
    return Object.keys(utils_1.pkgutil.pkgInfo('com.apple.pkg.RosettaUpdateAuto')).length > 0;
}
function installRosetta2() {
    (0, utils_1.exec)('softwareupdate --install-rosetta --agree-to-license');
}
